@@ -1,8 +1,8 @@
-# $Id: Proxy.pm,v 1.10 2004/05/13 19:51:21 fil Exp $
+# $Id: Proxy.pm,v 1.11 2005/06/09 04:20:55 fil Exp $
 package POE::Component::IKC::Proxy;
 
 ##############################################################################
-# $Id: Proxy.pm,v 1.10 2004/05/13 19:51:21 fil Exp $
+# $Id: Proxy.pm,v 1.11 2005/06/09 04:20:55 fil Exp $
 # Copyright 1999,2002,2004 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -21,7 +21,7 @@ use POE::Component::IKC::Specifier;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_proxy);
-$VERSION = '0.1501';
+$VERSION = '0.18';
 
 sub DEBUG { 0 }
 
@@ -151,6 +151,10 @@ L<POE>, L<POE::Component::IKC>
 
 
 $Log: Proxy.pm,v $
+Revision 1.11  2005/06/09 04:20:55  fil
+Reconciled
+Added check to put() to a closed wheel in Channel
+
 Revision 1.10  2004/05/13 19:51:21  fil
 Moved to signal_handled
 
